# Toy cryptographic utilities

[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v0.json)](https://docs.astral.sh/ruff/)
![Linting status](https://github.com/jpgoldberg/toy-crypto-math/actions/workflows/lint.yml/badge.svg)
![Tests status](https://github.com/jpgoldberg/toy-crypto-math/actions/workflows/pytest.yml/badge.svg)
[![Documentation](https://github.com/jpgoldberg/toy-crypto-math/actions/workflows/docs.yml/badge.svg)][documentation]
[![PyPI](https://img.shields.io/pypi/v/toycrypto?label=pypi%20package)](https://pypi.org/project/toycrypto/)
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://hatch.pypa.io/latest/)
[![License: MIT](https://img.shields.io/badge/license-MIT-C06524)](https://github.com/jpgoldberg/toy-crypto-math/blob/main/LICENSE.txt)

----

This is (almost certainly) not the package you are looking for.
The primary reason this is [published on PyPi][published] is so I can create reproducible Jupyter Notebooks.

See the [documentation] for use (or not) and [reasons why it exists](https://jpgoldberg.github.io/toy-crypto-math/#motivation).

Note that if you need to do cryptography in Python, I recommend [pyca](https://cryptography.io/).
If you want tools to explore the algebraic and number theoretic constructs used in cryptography,
look at [SageMath](https://doc.sagemath.org/).

[published]: https://pypi.org/project/toycrypto/ "toycrypto on PyPi"
[documentation]: https://jpgoldberg.github.io/toy-crypto-math/
